.. _debops.postldap:

debops.postldap
===============

The ``debops.postldap`` Ansible role can be used to configure and
manage a `Postfix` Virtual Mail server with an LDAP backend.
It allows configuration of Postfix using Ansible inventory variables.

.. toctree::
   :maxdepth: 3

   getting-started
   defaults/main
   guides
   ldap-dit

Copyright
---------

.. literalinclude:: ../../../../ansible/roles/debops.postldap/COPYRIGHT

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
